@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for B-Prolog 7.8 and later versions
-%  Last updated on March 19, 2019
+%  Last updated on August 5, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
@@ -499,7 +499,7 @@ findall(Term, Goal, List, Tail) :-
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	% B-Prolog bug workarund: up to version 8.1, the lines are returned end line first!
+	% B-Prolog bug workaround: up to version 8.1, the lines are returned end line first!
 	read_term(Stream, Term, [line_counts(LineEnd, LineBegin), variable_names(Variables0)| Options]),
 	% workaround lack of compliance of the variable_names/1 option
 	reverse(Variables0, Variables).
@@ -712,6 +712,9 @@ term_hash(_, _, _, _) :-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
+{X} :-
+	var(X),
+	throw(error(instantiation_error, logtalk({X}, _))).
 {*} :-
 	!,
 	logtalk_make(all).
