@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for JIProlog 4.1.6.1 or later versions
-%  Last updated on March 19, 2019
+%  Last updated on August 5, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
@@ -321,17 +321,17 @@
 '$lgt_ji_convert_file_path'(File, Converted) :-
 	atom_codes(File, FileCodes),
 	char_code('\\', Backslash),
-	char_code('/', Slah),
-	'$lgt_ji_reverse_slashes'(FileCodes, Backslash, Slah, ConvertedCodes),
+	char_code('/', Slash),
+	'$lgt_ji_reverse_slashes'(FileCodes, Backslash, Slash, ConvertedCodes),
 	atom_codes(Converted, ConvertedCodes).
 
 '$lgt_ji_reverse_slashes'([], _, _, []).
-'$lgt_ji_reverse_slashes'([Code| Codes], Backslash, Slah, [ConvertedCode| ConvertedCodes]) :-
+'$lgt_ji_reverse_slashes'([Code| Codes], Backslash, Slash, [ConvertedCode| ConvertedCodes]) :-
 	(	Code =:= Backslash ->
-		ConvertedCode = Slah
+		ConvertedCode = Slash
 	;	ConvertedCode = Code
 	),
-	'$lgt_ji_reverse_slashes'(Codes, Backslash, Slah, ConvertedCodes).
+	'$lgt_ji_reverse_slashes'(Codes, Backslash, Slash, ConvertedCodes).
 
 
 % '$lgt_change_directory'(+atom)
@@ -639,6 +639,9 @@ term_hash(_, _, _, _) :-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
+{X} :-
+	var(X),
+	throw(error(instantiation_error, logtalk({X}, _))).
 {*} :-
 	!,
 	logtalk_make(all).
